//[mahjong-utils](../../../index.md)/[mahjongutils.shanten](../index.md)/[ShantenWithFuroChance](index.md)/[ShantenWithFuroChance](-shanten-with-furo-chance.md)

# ShantenWithFuroChance

[common]\
constructor(shantenNum: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html), pass: [ShantenWithoutGot](../-shanten-without-got/index.md)?, chi: [Map](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-map/index.html)&lt;[Tatsu](../../mahjongutils.models/-tatsu/index.md), [ShantenWithGot](../-shanten-with-got/index.md)&gt;, pon: [ShantenWithGot](../-shanten-with-got/index.md)?, minkan: [ShantenWithoutGot](../-shanten-without-got/index.md)?)
